@@ -1,4 +1,7 @@
 #!/usr/bin/python
+
+import sys
+
 def main(raw_args=None):
     from .. import SonosExtrasCliHelper, __version__
     # import sonos_extras
@@ -60,8 +63,7 @@ def main(raw_args=None):
     if   args.sub_command in ["current", "c"]:
         print(client.get_current_status())
     elif args.sub_command in ["version", "ver"]:
-        # import sonos_extras
-        return __version__
+        print(__version__)
     elif args.sub_command in ["queue", "q"]:
         client.print_queue(args.i, args.n)
     elif args.sub_command in ["volume", "v"]:
@@ -70,7 +72,7 @@ def main(raw_args=None):
             client.safe_set_volume(client.volume + (int(args.action) * n), args.force)
         elif args.n:
             client.safe_set_volume(int(args.n), args.force)
-        return client.volume
+        print(client.volume)
     elif args.sub_command == "p":
         if client.get_current_transport_info()['current_transport_state'] in ["STOPPED", "PAUSED_PLAYBACK"]:
             client.play()
@@ -95,9 +97,9 @@ def main(raw_args=None):
         position = client.add_uri_to_queue(uri, args.uArgs[1] if len(args.uArgs) > 1 else 0)
         print(position, '|', uri)
     elif args.sub_command in ["playlists", "pls"]:
-        return client.playlists()
+        print(client.playlists())
     elif args.sub_command == "playlist":
         client.playlist(args.uArgs[0] if args.uArgs else "")
 
 if __name__ == "__main__":
-    print(main())
\ No newline at end of file
+    main()
\ No newline at end of file
